==> haskell-uuid-1.3.13-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uuid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uuid
version:              1.3.13
visibility:           public
id:                   uuid-1.3.13-KVLAXPDszhvKH9dJ3ggIRS
key:                  uuid-1.3.13-KVLAXPDszhvKH9dJ3ggIRS
license:              BSD-3-Clause
copyright:            (c) 2008-2014 Antoine Latter
maintainer:           hvr@gnu.org
author:               Antoine Latter
homepage:             https://github.com/hvr/uuid
synopsis:
    For creating, comparing, parsing and printing Universally Unique Identifiers

description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.

    See <http://en.wikipedia.org/wiki/UUID> for the general idea.

category:             Data
abi:                  42a7c72b85583abab3c029fe96c46427
exposed:              True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5

hidden-modules:       Data.UUID.Named Data.Word.Util
import-dirs:          /usr/lib/ghc-8.10.3/site-local/uuid-1.3.13
library-dirs:         /usr/lib/ghc-8.10.3/site-local/uuid-1.3.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/uuid-1.3.13
hs-libraries:         HSuuid-1.3.13-KVLAXPDszhvKH9dJ3ggIRS
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.12.0
    cryptohash-md5-0.11.100.1-CgMOlYdwfGgA8JlRkdDkSV
    cryptohash-sha1-0.11.100.1-GwOGlQ9i8hY1wQXawIaKuh
    entropy-0.4.1.6-6Z0sejCw1fy7sJ1AU1oQ6y
    network-info-0.2.0.10-LJXZu231xIy8KJ0QI8k9yv
    random-1.2.0-52OpOPhBQ1G1x1onrVvBUa text-1.2.4.1 time-1.9.3
    uuid-types-1.0.3-Gcby7cPtQKTCWkja4RsVD3

haddock-interfaces:   /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html:         /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-1.3.13-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uuid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uuid
version:              1.3.13
visibility:           public
id:                   uuid-1.3.13-ADxq9WhsXSx2sDiqo3hi5i
key:                  uuid-1.3.13-ADxq9WhsXSx2sDiqo3hi5i
license:              BSD-3-Clause
copyright:            (c) 2008-2014 Antoine Latter
maintainer:           hvr@gnu.org
author:               Antoine Latter
homepage:             https://github.com/hvr/uuid
synopsis:
    For creating, comparing, parsing and printing Universally Unique Identifiers

description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.

    See <http://en.wikipedia.org/wiki/UUID> for the general idea.

category:             Data
abi:                  df8a484f2a0e632ef1406b98a5cc15c5
exposed:              True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5

hidden-modules:       Data.UUID.Named Data.Word.Util
import-dirs:          /usr/lib/ghc-8.10.3/site-local/uuid-1.3.13
library-dirs:         /usr/lib/ghc-8.10.3/site-local/uuid-1.3.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/uuid-1.3.13
hs-libraries:         HSuuid-1.3.13-ADxq9WhsXSx2sDiqo3hi5i
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.12.0
    cryptohash-md5-0.11.100.1-CgMOlYdwfGgA8JlRkdDkSV
    cryptohash-sha1-0.11.100.1-GwOGlQ9i8hY1wQXawIaKuh
    entropy-0.4.1.6-6Z0sejCw1fy7sJ1AU1oQ6y
    network-info-0.2.0.10-LJXZu231xIy8KJ0QI8k9yv
    random-1.2.0-2oMeoq1l81e2o54ELOj6Jv text-1.2.4.1 time-1.9.3
    uuid-types-1.0.3-5VRqGLNh0xC7zxnTfTkBca

haddock-interfaces:   /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html:         /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
